@@ -2,6 +2,8 @@ from .component import Component
 
 class Script(Component):
 
+    __slots__ = ["_priority",]
+
     def __init__(self, priority=0, name="Script"):
         super().__init__(Component.TYPE_SCRIPT, name)
         # Store priority value
@@ -12,6 +14,10 @@ class Script(Component):
 
     def setPriority(self, newP):
         self._priority = newP
+        scn = self.getScene()
+        if scn != None:
+            scn.notifyChangeScriptPriority(self)
 
     def getPriority(self):
-        return self._priority
\ No newline at end of file
+        return self._priority
+
